@@ -11,7 +11,11 @@ class DispatchBase(object):
     def register_app(self, name, app):
         self.applications[name] = app
 
+    def get_extra_environ(self):
+        return {}
+
     def __call__(self, environ, start_response):
+        environ.update(self.get_extra_environ())
         view_name = self.detect_view_name(environ)
         if view_name is None:
             return self.on_view_not_found(environ, start_response)
